@@ -1,28 +1,28 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "customtoolswidgetng_gui.h"
-#include "customtools/customtoolswidgetng.h"
 #include "customtools/customtoolspluginmanager.h"
-#include <QStandardPaths>
+#include "customtools/customtoolswidgetng.h"
 #include <KToggleAction>
+#include <QStandardPaths>
 
-#include <QVBoxLayout>
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QToolBar>
+#include <QVBoxLayout>
 
 #include <KXmlGui/kactioncollection.h>
 
 CustomToolWidgetNgTest::CustomToolWidgetNgTest(QWidget *parent)
     : QWidget(parent)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
 
-    auto *menu = new QToolBar(this);
+    auto menu = new QToolBar(this);
     lay->addWidget(menu);
 
     mCustomTools = new PimCommon::CustomToolsWidgetNg(this);
@@ -48,7 +48,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    auto *w = new CustomToolWidgetNgTest();
+    auto w = new CustomToolWidgetNgTest();
     w->resize(800, 200);
     w->show();
     const int ret = app.exec();
