@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ADDRESSEELINEEDITUTILTEST_H
-#define ADDRESSEELINEEDITUTILTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,11 +13,10 @@ class AddresseeLineEditUtilTest : public QObject
     Q_OBJECT
 public:
     explicit AddresseeLineEditUtilTest(QObject *parent = nullptr);
-    ~AddresseeLineEditUtilTest();
+    ~AddresseeLineEditUtilTest() override;
 
 private Q_SLOTS:
     void shouldAdaptPasteMails_data();
     void shouldAdaptPasteMails();
 };
 
-#endif // ADDRESSEELINEEDITUTILTEST_H
